@@ -1,23 +1,25 @@
-/* $Id: procuid.h,v 1.9 1998/10/11 18:14:11 martin Exp $ */
+/* $Id: procuid.h,v 1.13 1999/02/23 11:43:13 martin Exp $ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_PROCUID_H__
 #define __GLIBTOP_PROCUID_H__
@@ -25,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_PROC_UID_UID		0
 #define GLIBTOP_PROC_UID_EUID		1
@@ -71,14 +73,14 @@ struct _glibtop_proc_uid
 #define glibtop_get_proc_uid_r		glibtop_get_proc_uid_s
 #endif
 
-extern void glibtop_get_proc_uid_l __P((glibtop *, glibtop_proc_uid *, pid_t));
+void glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_UID
-extern void glibtop_init_proc_uid_p __P((glibtop *));
-extern void glibtop_get_proc_uid_p __P((glibtop *, glibtop_proc_uid *, pid_t));
+void glibtop_init_proc_uid_p (glibtop *server);
+void glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #else
-extern void glibtop_init_proc_uid_s __P((glibtop *));
-extern void glibtop_get_proc_uid_s __P((glibtop *, glibtop_proc_uid *, pid_t));
+void glibtop_init_proc_uid_s (glibtop *server);
+void glibtop_get_proc_uid_s (glibtop *server, glibtop_proc_uid *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
@@ -92,6 +94,6 @@ extern const char *glibtop_descriptions_proc_uid [];
 
 #endif
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
