@@ -1,4 +1,4 @@
-/* $Id: glibtop_suid.h,v 1.6 1999/02/23 11:43:58 martin Exp $ */
+/* $Id: glibtop_suid.h,v 1.6.2.1 1999/05/27 18:41:50 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,6 +26,10 @@
 
 BEGIN_LIBGTOP_DECLS
 
+#if _IN_LIBGTOP
+#include <sys/param.h>
+#endif
+
 #define KI_PROC(ki) (&(ki))->kp_proc)
 #define KI_EPROC(ki) (&(ki))->kp_eproc)
 
