@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.13 1999/02/23 11:44:01 martin Exp $ */
+/* $Id: mem.c,v 1.13.4.3 1999/05/27 18:56:47 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -31,14 +31,19 @@
 #include <sys/vmmeter.h>
 #include <vm/vm_param.h>
 
-static const unsigned long _glibtop_sysdeps_mem =
-(1 << GLIBTOP_MEM_TOTAL) + (1 << GLIBTOP_MEM_USED) +
-(1 << GLIBTOP_MEM_FREE) + (1 << GLIBTOP_MEM_SHARED) +
-(1 << GLIBTOP_MEM_BUFFER) +
-#ifdef __FreeBSD__
-(1 << GLIBTOP_MEM_CACHED) +
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+#include <uvm/uvm_extern.h>
 #endif
-(1 << GLIBTOP_MEM_USER) + (1 << GLIBTOP_MEM_LOCKED);
+
+static const unsigned long _glibtop_sysdeps_mem =
+(1L << GLIBTOP_MEM_TOTAL) + (1L << GLIBTOP_MEM_USED) +
+(1L << GLIBTOP_MEM_FREE) +
+(1L << GLIBTOP_MEM_SHARED) +
+(1L << GLIBTOP_MEM_BUFFER) +
+#ifdef __FreeBSD__
+(1L << GLIBTOP_MEM_CACHED) +
+#endif
+(1L << GLIBTOP_MEM_USER) + (1L << GLIBTOP_MEM_LOCKED);
 
 #ifndef LOG1024
 #define LOG1024		10
@@ -52,18 +57,33 @@ static int pageshift;		/* log base 2 of the pagesize */
 
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-	{ "_cnt" },
-#ifdef __FreeBSD__
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	{ "_bufpages" },
+	{ 0 }
+#else
+#if defined(__bsdi__)
+	{ "_bufcachemem" },
+#elif defined(__FreeBSD__)
 	{ "_bufspace" },
 #else
 	{ "_bufpages" },
 #endif
+	{ "_cnt" },
 	{ 0 }
+#endif
 };
 
 /* MIB array for sysctl */
-/* static int mib_length=2; */
+static int mib_length=2;
+#ifdef __bsdi__
+static int mib [] = { CTL_VM, VM_TOTAL };
+#else
 static int mib [] = { CTL_VM, VM_METER };
+#endif
+
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+static int mib_uvmexp [] = { CTL_VM, VM_UVMEXP };
+#endif
 
 /* Init function. */
 
@@ -97,12 +117,18 @@ glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 {
 	struct vmtotal vmt;
 	size_t length_vmt;
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	struct uvmexp uvmexp;
+	size_t length_uvmexp;
+#else
 	struct vmmeter vmm;
+#endif
 	u_int v_used_count;
 	u_int v_total_count;
+	u_int v_free_count;
 	int bufspace;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MEM), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MEM), 0);
 	
 	memset (buf, 0, sizeof (glibtop_mem));
 
@@ -116,18 +142,26 @@ glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
 	/* Get the data from sysctl */
 	length_vmt = sizeof (vmt);
 	if (sysctl (mib, 2, &vmt, &length_vmt, NULL, 0)) {
-		glibtop_warn_io_r (server, "sysctl");
+		glibtop_warn_io_r (server, "sysctl (vmt)");
 		return;
 	}
-	
+
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	length_uvmexp = sizeof (uvmexp);
+	if (sysctl (mib_uvmexp, 2, &uvmexp, &length_uvmexp, NULL, 0)) {
+		glibtop_warn_io_r (server, "sysctl (uvmexp)");
+		return;
+	}
+#else
 	/* Get the data from kvm_* */
-	if (kvm_read (server->machine.kd, nlst[0].n_value,
+	if (kvm_read (server->machine.kd, nlst[1].n_value,
 		      &vmm, sizeof (vmm)) != sizeof (vmm)) {
 		glibtop_warn_io_r (server, "kvm_read (cnt)");
 		return;
 	}
+#endif
 
-	if (kvm_read (server->machine.kd, nlst[1].n_value,
+	if (kvm_read (server->machine.kd, nlst[0].n_value,
 		      &bufspace, sizeof (bufspace)) != sizeof (bufspace)) {
 		glibtop_warn_io_r (server, "kvm_read (bufspace)");
 		return;
@@ -135,25 +169,43 @@ glibtop_get_mem_p (glibtop *server, glibtop_mem *buf)
   
 	/* convert memory stats to Kbytes */
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__)
 	v_total_count = vmm.v_page_count;
+#else
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	v_total_count = uvmexp.reserve_kernel +
+		uvmexp.reserve_pagedaemon +
+		uvmexp.free + uvmexp.wired + uvmexp.active +
+		uvmexp.inactive;
 #else
 	v_total_count = vmm.v_kernel_pages +
 		vmm.v_free_count + vmm.v_wire_count +
 		vmm.v_active_count + vmm.v_inactive_count;
 #endif
+#endif
 
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	v_used_count = uvmexp.active + uvmexp.inactive;
+	v_free_count = uvmexp.free;
+#else
 	v_used_count = vmm.v_active_count + vmm.v_inactive_count;
+	v_free_count = vmm.v_free_count;
+#endif
 
 	buf->total = (u_int64_t) pagetok (v_total_count) << LOG1024;
 	buf->used  = (u_int64_t) pagetok (v_used_count) << LOG1024;
-	buf->free  = (u_int64_t) pagetok (vmm.v_free_count) << LOG1024;
+	buf->free  = (u_int64_t) pagetok (v_free_count) << LOG1024;
 
 #ifdef __FreeBSD__
 	buf->cached = (u_int64_t) pagetok (vmm.v_cache_count) << LOG1024;
 #endif
 
+#if defined(__NetBSD__)  && (__NetBSD_Version__ >= 104000000)
+	buf->locked = (u_int64_t) pagetok (uvmexp.wired) << LOG1024;
+#else
 	buf->locked = (u_int64_t) pagetok (vmm.v_wire_count) << LOG1024;
+#endif
+
 	buf->shared = (u_int64_t) pagetok (vmt.t_rmshr) << LOG1024;
 
 #if __FreeBSD__
