@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.9 1999/02/23 11:44:02 martin Exp $ */
+/* $Id: msg_limits.c,v 1.9.4.2 1999/05/27 14:03:58 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,9 +27,26 @@
 
 #include <glibtop_suid.h>
 
+#if (defined __bsdi__) && (_BSDI_VERSION < 199700)
+/* Older versions of BSDI don't seem to have this. */
+
+void
+glibtop_init_msg_limits_p (glibtop *server)
+{ }
+
+void
+glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
+{
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
+
+        memset (buf, 0, sizeof (glibtop_msg_limits));
+}
+
+#else
+
 /* #define KERNEL to get declaration of `struct msginfo'. */
 
-#ifdef __FreeBSD__
+#if (defined __FreeBSD__) || (defined __bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -39,9 +56,9 @@
 #include <sys/msg.h>
 
 static const unsigned long _glibtop_sysdeps_msg_limits =
-(1 << GLIBTOP_IPC_MSGMAX) + (1 << GLIBTOP_IPC_MSGMNI) +
-(1 << GLIBTOP_IPC_MSGMNB) + (1 << GLIBTOP_IPC_MSGTQL) +
-(1 << GLIBTOP_IPC_MSGSSZ);
+(1L << GLIBTOP_IPC_MSGMAX) + (1L << GLIBTOP_IPC_MSGMNI) +
+(1L << GLIBTOP_IPC_MSGMNB) + (1L << GLIBTOP_IPC_MSGTQL) +
+(1L << GLIBTOP_IPC_MSGSSZ);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_msginfo'
@@ -78,7 +95,7 @@ glibtop_init_msg_limits_p (glibtop *server)
 void
 glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_MSG_LIMITS), 0);
 	
 	memset (buf, 0, sizeof (glibtop_msg_limits));
 
@@ -93,3 +110,6 @@ glibtop_get_msg_limits_p (glibtop *server, glibtop_msg_limits *buf)
 	
 	buf->flags = _glibtop_sysdeps_msg_limits; 
 }
+
+#endif /* either a newer BSDI or no BSDI at all. */
+
