@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.7 1999/02/23 11:44:03 martin Exp $ */
+/* $Id: netload.c,v 1.7.4.2 1999/05/27 14:03:59 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,20 +39,20 @@
 #include <netinet/in_var.h>
 
 static const unsigned long _glibtop_sysdeps_netload =
-(1 << GLIBTOP_NETLOAD_IF_FLAGS) +
-(1 << GLIBTOP_NETLOAD_MTU) +
-(1 << GLIBTOP_NETLOAD_SUBNET) +
-(1 << GLIBTOP_NETLOAD_ADDRESS) +
-(1 << GLIBTOP_NETLOAD_PACKETS_IN) +
-(1 << GLIBTOP_NETLOAD_PACKETS_OUT) +
-(1 << GLIBTOP_NETLOAD_PACKETS_TOTAL) +
-(1 << GLIBTOP_NETLOAD_BYTES_IN) +
-(1 << GLIBTOP_NETLOAD_BYTES_OUT) +
-(1 << GLIBTOP_NETLOAD_BYTES_TOTAL) +
-(1 << GLIBTOP_NETLOAD_ERRORS_IN) +
-(1 << GLIBTOP_NETLOAD_ERRORS_OUT) +
-(1 << GLIBTOP_NETLOAD_ERRORS_TOTAL) +
-(1 << GLIBTOP_NETLOAD_COLLISIONS);
+(1L << GLIBTOP_NETLOAD_IF_FLAGS) +
+(1L << GLIBTOP_NETLOAD_MTU) +
+(1L << GLIBTOP_NETLOAD_SUBNET) +
+(1L << GLIBTOP_NETLOAD_ADDRESS) +
+(1L << GLIBTOP_NETLOAD_PACKETS_IN) +
+(1L << GLIBTOP_NETLOAD_PACKETS_OUT) +
+(1L << GLIBTOP_NETLOAD_PACKETS_TOTAL) +
+(1L << GLIBTOP_NETLOAD_BYTES_IN) +
+(1L << GLIBTOP_NETLOAD_BYTES_OUT) +
+(1L << GLIBTOP_NETLOAD_BYTES_TOTAL) +
+(1L << GLIBTOP_NETLOAD_ERRORS_IN) +
+(1L << GLIBTOP_NETLOAD_ERRORS_OUT) +
+(1L << GLIBTOP_NETLOAD_ERRORS_TOTAL) +
+(1L << GLIBTOP_NETLOAD_COLLISIONS);
 
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
@@ -87,7 +87,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	struct in_ifaddr in;
     } ifaddr;
     
-    glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_NETLOAD), 0);
+    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_NETLOAD), 0);
 	
     memset (buf, 0, sizeof (glibtop_netload));
 
@@ -107,7 +107,7 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 			  sizeof (ifnet)) != sizeof (ifnet))
 		    glibtop_error_io_r (server, "kvm_read (ifnetaddr)");
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__bsdi__)
 	    if (kvm_read (server->machine.kd, (u_long) ifnet.if_name,
 			  tname, 16) != 16)
 		    glibtop_error_io_r (server, "kvm_read (if_name)");
@@ -116,9 +116,9 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 	    tname [15] = 0;
 #endif
 
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+#if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
 	    ifaddraddr = (u_long) ifnet.if_addrhead.tqh_first;
-#elif (defined __FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__bsdi__)
 	    ifaddraddr = (u_long) ifnet.if_addrlist;
 #else
 	    ifaddraddr = (u_long) ifnet.if_addrlist.tqh_first;
@@ -194,18 +194,18 @@ glibtop_get_netload_p (glibtop *server, glibtop_netload *buf,
 		return;
 	    }
 
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+#if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
 	    ifaddraddr = (u_long)ifaddr.ifa.ifa_link.tqe_next;
-#elif (defined __FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__bsdi__)
 	    ifaddraddr = (u_long)ifaddr.ifa.ifa_next;
 #else
 	    ifaddraddr = (u_long)ifaddr.ifa.ifa_list.tqe_next;
 #endif
 	}
 	
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+#if defined(__FreeBSD__) && (__FreeBSD_version >= 300000)
 	ifnetaddr = (u_long) ifnet.if_link.tqe_next;
-#elif (defined __FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__bsdi__)
 	ifnetaddr = (u_long) ifnet.if_next;
 #else
 	ifnetaddr = (u_long) ifnet.if_list.tqe_next;
