@@ -1,4 +1,4 @@
-/* $Id: ppp.c,v 1.5 1999/02/23 11:44:06 martin Exp $ */
+/* $Id: ppp.c,v 1.5.4.3 1999/05/27 14:04:00 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,7 +39,7 @@
 #include <net/netisr.h>
 #include <net/route.h>
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__NetBSD__)
 #include <net/if_sppp.h>
 #else
 #include <i4b/sppp/if_sppp.h>
@@ -51,11 +51,11 @@
 #endif
 
 static const unsigned long _glibtop_sysdeps_ppp =
-(1 << GLIBTOP_PPP_STATE);
+(1L << GLIBTOP_PPP_STATE);
 
 #ifdef HAVE_I4B_ACCT
 static const unsigned long _glibtop_sysdeps_ppp_acct =
-(1 << GLIBTOP_PPP_BYTES_IN) + (1 << GLIBTOP_PPP_BYTES_OUT);
+(1L << GLIBTOP_PPP_BYTES_IN) + (1L << GLIBTOP_PPP_BYTES_OUT);
 #endif
 
 #endif /* HAVE_I4B */
@@ -99,7 +99,7 @@ glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
 #endif
 	int phase;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PPP), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PPP), 0);
 	
 	memset (buf, 0, sizeof (glibtop_ppp));
 
@@ -110,10 +110,15 @@ glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
 #ifdef HAVE_I4B_ACCT
 	phase = data.sc_if_un.scu_sp.pp_phase;
 #else
+	/* FIXME: Which FreeBSD version have this field and
+	 *        which not. */
+#if 0
 	phase = data.pp_phase;
+#endif
 #endif
 
 	switch (phase) {
+#ifdef HAVE_I4B_ACCT
 	case PHASE_DEAD:
 	case PHASE_TERMINATE:
 		buf->state = GLIBTOP_PPP_STATE_HANGUP;
@@ -122,6 +127,7 @@ glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
 	case PHASE_NETWORK:
 		buf->state = GLIBTOP_PPP_STATE_ONLINE;
 		break;
+#endif
 	default:
 		buf->state = GLIBTOP_PPP_STATE_UNKNOWN;
 		break;
