@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.10 1999/02/23 11:44:14 martin Exp $ */
+/* $Id: procsegment.c,v 1.10.2.1 1999/05/27 14:04:08 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -48,7 +48,7 @@ glibtop_get_proc_segment_p (glibtop *server,
 			    glibtop_proc_segment *buf,
 			    pid_t pid)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_segment));
 
