@@ -1,4 +1,4 @@
-/* $Id: sem_limits.c,v 1.8 1999/02/23 11:44:19 martin Exp $ */
+/* $Id: sem_limits.c,v 1.8.4.2 1999/05/27 14:04:13 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,9 +27,26 @@
 
 #include <glibtop_suid.h>
 
+#if defined(__bsdi__) && (_BSDI_VERSION < 199700)
+/* Older versions of BSDI don't seem to have this. */
+
+void
+glibtop_init_sem_limits_p (glibtop *server)
+{ }
+
+void
+glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
+{
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
+
+        memset (buf, 0, sizeof (glibtop_sem_limits));
+}
+
+#else
+
 /* #define KERNEL to get declaration of `struct seminfo'. */
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -39,11 +56,11 @@
 #include <sys/sem.h>
 
 static unsigned long _glibtop_sysdeps_sem_limits =
-(1 << GLIBTOP_IPC_SEMMAP) + (1 << GLIBTOP_IPC_SEMMNI) +
-(1 << GLIBTOP_IPC_SEMMNS) + (1 << GLIBTOP_IPC_SEMMNU) +
-(1 << GLIBTOP_IPC_SEMMSL) + (1 << GLIBTOP_IPC_SEMOPM) +
-(1 << GLIBTOP_IPC_SEMUME) + (1 << GLIBTOP_IPC_SEMUSZ) +
-(1 << GLIBTOP_IPC_SEMVMX) + (1 << GLIBTOP_IPC_SEMAEM);
+(1L << GLIBTOP_IPC_SEMMAP) + (1L << GLIBTOP_IPC_SEMMNI) +
+(1L << GLIBTOP_IPC_SEMMNS) + (1L << GLIBTOP_IPC_SEMMNU) +
+(1L << GLIBTOP_IPC_SEMMSL) + (1L << GLIBTOP_IPC_SEMOPM) +
+(1L << GLIBTOP_IPC_SEMUME) + (1L << GLIBTOP_IPC_SEMUSZ) +
+(1L << GLIBTOP_IPC_SEMVMX) + (1L << GLIBTOP_IPC_SEMAEM);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_seminfo'
@@ -80,7 +97,7 @@ glibtop_init_sem_limits_p (glibtop *server)
 void
 glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SEM_LIMITS), 0);
 	
 	memset (buf, 0, sizeof (glibtop_sem_limits));
 	
@@ -98,3 +115,6 @@ glibtop_get_sem_limits_p (glibtop *server, glibtop_sem_limits *buf)
 	
 	buf->flags = _glibtop_sysdeps_sem_limits;
 }
+
+#endif /* either a newer BSDI or no BSDI at all. */
+
