@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.8 1999/02/23 11:44:20 martin Exp $ */
+/* $Id: shm_limits.c,v 1.8.4.2 1999/05/27 14:04:14 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,9 +27,26 @@
 
 #include <glibtop_suid.h>
 
+#if defined(__bsdi__) && (_BSDI_VERSION < 199700)
+/* Older versions of BSDI don't seem to have this. */
+
+void
+glibtop_init_shm_limits_p (glibtop *server)
+{ }
+
+void
+glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
+{
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+
+        memset (buf, 0, sizeof (glibtop_shm_limits));
+}
+
+#else
+
 /* #define KERNEL to get declaration of `struct shminfo'. */
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__)  || defined(__bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -39,9 +56,9 @@
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1 << GLIBTOP_IPC_SHMMAX) + (1 << GLIBTOP_IPC_SHMMIN) +
-(1 << GLIBTOP_IPC_SHMMNI) + (1 << GLIBTOP_IPC_SHMSEG) +
-(1 << GLIBTOP_IPC_SHMALL);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
+(1L << GLIBTOP_IPC_SHMALL);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_shminfo'
@@ -78,7 +95,7 @@ glibtop_init_shm_limits_p (glibtop *server)
 void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 	
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
@@ -93,3 +110,6 @@ glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 
 	buf->flags = _glibtop_sysdeps_shm_limits;
 }
+
+#endif /* either a newer BSDI or no BSDI at all. */
+
