@@ -1,23 +1,25 @@
-/* $Id: glibtop_server.h,v 1.6 1998/10/26 10:39:05 martin Exp $ */
+/* $Id: glibtop_server.h,v 1.9 1999/02/23 11:44:55 martin Exp $ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
@@ -25,7 +27,7 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #ifdef _IN_LIBGTOP
 
@@ -127,6 +129,6 @@ proc_stat_after_cmd (char *p)
 #define GLIBTOP_SUID_NETLOAD		0
 #define GLIBTOP_SUID_PPP		0
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
