@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.13.2.1 1999/05/27 19:24:16 martin Exp $ */
+/* $Id: netload.c,v 1.13.2.2 1999/09/16 21:05:33 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -112,8 +112,6 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
     skfd = socket (AF_INET, SOCK_DGRAM, 0);
     if (skfd) {
 	struct ifreq ifr;
-	struct sockaddr_in addr;
-	char *address;
 	unsigned flags;
 
 	strcpy (ifr.ifr_name, interface);
