@@ -1,4 +1,4 @@
-/* $Id: procargs.c,v 1.3 1999/02/23 11:45:03 martin Exp $ */
+/* $Id: procargs.c,v 1.3.2.1 1999/05/27 19:24:18 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop/procargs.h>
 
 static const unsigned long _glibtop_sysdeps_proc_args =
-(1 << GLIBTOP_PROC_ARGS_SIZE);
+(1L << GLIBTOP_PROC_ARGS_SIZE);
 
 /* Init function. */
 
