@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.14 1999/02/23 11:45:10 martin Exp $ */
+/* $Id: procstate.c,v 1.14.4.1 1999/05/27 19:24:25 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,10 +28,10 @@
 #include <sys/stat.h>
 
 static const unsigned long _glibtop_sysdeps_proc_state =
-(1 << GLIBTOP_PROC_STATE_CMD) + (1 << GLIBTOP_PROC_STATE_STATE);
+(1L << GLIBTOP_PROC_STATE_CMD) + (1L << GLIBTOP_PROC_STATE_STATE);
 
 static const unsigned long _glibtop_sysdeps_proc_state_uid =
-(1 << GLIBTOP_PROC_STATE_UID) + (1 << GLIBTOP_PROC_STATE_GID);
+(1L << GLIBTOP_PROC_STATE_UID) + (1L << GLIBTOP_PROC_STATE_GID);
 
 /* Init function. */
 
