@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.16 1999/02/23 11:45:16 martin Exp $ */
+/* $Id: swap.c,v 1.16.2.1 1999/05/27 19:24:30 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,11 +28,11 @@
 #include <fcntl.h>
 
 static unsigned long _glibtop_sysdeps_swap =
-(1 << GLIBTOP_SWAP_TOTAL) + (1 << GLIBTOP_SWAP_USED) +
-(1 << GLIBTOP_SWAP_FREE);
+(1L << GLIBTOP_SWAP_TOTAL) + (1L << GLIBTOP_SWAP_USED) +
+(1L << GLIBTOP_SWAP_FREE);
 
 static unsigned long _glibtop_sysdeps_swap_paging =
-(1 << GLIBTOP_SWAP_PAGEIN) + (1 << GLIBTOP_SWAP_PAGEOUT);
+(1L << GLIBTOP_SWAP_PAGEIN) + (1L << GLIBTOP_SWAP_PAGEOUT);
 
 /* Init function. */
 
