@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.11 1999/02/23 11:45:18 martin Exp $ */
+/* $Id: uptime.c,v 1.11.2.1 1999/05/27 19:24:32 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,7 @@
 #include <glibtop/uptime.h>
 
 static unsigned long _glibtop_sysdeps_uptime =
-(1 << GLIBTOP_UPTIME_UPTIME) + (1 << GLIBTOP_UPTIME_IDLETIME);
+(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
 
 /* Init function. */
 
