@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.7 1999/02/23 11:46:12 martin Exp $ */
+/* $Id: swap.c,v 1.7.2.1 1999/05/27 19:30:29 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,8 +26,8 @@
 #include <glibtop/swap.h>
 
 static unsigned long _glibtop_sysdeps_swap =
-(1 << GLIBTOP_SWAP_TOTAL) + (1 << GLIBTOP_SWAP_USED) +
-(1 << GLIBTOP_SWAP_FREE);
+(1L << GLIBTOP_SWAP_TOTAL) + (1L << GLIBTOP_SWAP_USED) +
+(1L << GLIBTOP_SWAP_FREE);
 
 /* Init function. */
 
